@@ -107,8 +107,6 @@ class pygtide(object):
         pygtide.init() initialises the etpred (Fortran) module and sets global variables
         """
         self.msg = msg
-        self.version = 'PyGTide v0.6'
-        self.exectime = 0
         self.fortran_version = etpred.inout.vers.astype(str)
         self.data_dir = resource_filename('pygtide', 'commdat/')
         etpred.params.comdir = self.data_dir + ' ' * (256 - len(self.data_dir))
@@ -138,7 +136,6 @@ class pygtide(object):
         """
         self.update() refreshes the variables of PyGTide based on the Fortran module etpred
         """
-        self.exectime = etpred.inout.exectime
         self.headers = np.char.strip(etpred.inout.header.astype('str'))
         self.args = etpred.inout.argsin
         self.unit = etpred.inout.etpunit.astype('str')
@@ -365,23 +362,15 @@ class pygtide(object):
         # test that samprate is not larger than duration
         if (samprate/3600 >  duration):
             raise ValueError("samprate exceeds duration!")
-        # ####################################################
-        # BUGFIX: fix a weird bug where the program stops before
-        # the etpdata table is filled completely
-        argsin[6] = duration + 1
-        # run prediction routine
-        # ######################################################
         # print(argsin)
         self.args = argsin
         if self.msg:
             print('%s is calculating, please wait ...' % (self.fortran_version))
-
+        
+        # hand over variables
         etpred.predict(argsin)
 
         self.exec = True
-        self.exectime = etpred.inout.exectime
-        if self.msg:
-            print('Done after %.3f s.' % (self.exectime))
         self.update()
         return True
 
@@ -395,19 +384,23 @@ class pygtide(object):
         keyword 'digits' sets the number of digits returned.
         """
         if self.exec:
-            # format date and time into padded number strings
-#            print(etpred.inout.etpdata[:,1])
-            date = np.char.mod("%08.0f ", etpred.inout.etpdata[:,0])
-            time = np.char.mod("%06.0f", etpred.inout.etpdata[:,1])
-            # merge date and time arrays
-            datetime = np.core.defchararray.add(date, time)
             # get the headers from Fortran
             cols = np.char.strip(etpred.inout.header.astype('str'))
             allcols = np.insert(cols[2:], 0, 'UTC')
             etdata = pd.DataFrame(columns=allcols)
+            # format date and time into padded number strings
+            etpred_data = np.array(etpred.inout.etpdata)
+            # print(etpred.inout.etpdata[:, 0])
+            # catch non-complete container fills from odd duration/sampling pairs
+            etpred_data = etpred_data[etpred_data[:,0] > 0, :]
+            # convert 
+            date = np.char.mod("%08.0f ", etpred_data[:,0])
+            time = np.char.mod("%06.0f", etpred_data[:,1])
+            # merge date and time arrays
+            datetime = np.core.defchararray.add(date, time)
             etdata['UTC'] = pd.to_datetime(datetime, format="%Y%m%d %H%M%S", utc=True)
             # obtain header strings from routine and convert
-            etdata[cols[2:]] = np.around(etpred.inout.etpdata[:, 2:], digits)
+            etdata[cols[2:]] = np.around(etpred_data[:, 2:], digits)
             return etdata
         else:
             return None
